@@ -165,9 +165,11 @@ class BuildTest(unittest.TestCase):
         self.assertEqual(etree.tostring(root), raw)
         from lxml import html
         html.fromstring('<p>\U0001f63a')
-        from calibre.utils.xml_parse import safe_xml_fromstring
+        from calibre.utils.xml_parse import safe_html_fromstring, safe_xml_fromstring
         bad = '\U0001f468' * 8192
-        safe_xml_fromstring(f'<p>{bad}</p>')
+        bad = f'<p>{bad}</p>'
+        safe_xml_fromstring(bad)
+        safe_html_fromstring(bad)
 
     def test_certgen(self):
         from calibre.utils.certgen import create_key_pair
